summaryrefslogtreecommitdiffstats
path: root/chrome/browser/dom_ui/dom_ui.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/dom_ui/dom_ui.h
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/dom_ui/dom_ui.h')
-rw-r--r--chrome/browser/dom_ui/dom_ui.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chrome/browser/dom_ui/dom_ui.h b/chrome/browser/dom_ui/dom_ui.h
index 68db631..3c2dc16 100644
--- a/chrome/browser/dom_ui/dom_ui.h
+++ b/chrome/browser/dom_ui/dom_ui.h
@@ -20,13 +20,13 @@ class GURL;
class Profile;
class RenderViewHost;
class Value;
-class WebContents;
+class TabContents;
// A DOMUI sets up the datasources and message handlers for a given HTML-based
// UI. It is contained by a DOMUIManager.
class DOMUI {
public:
- explicit DOMUI(WebContents* contents);
+ explicit DOMUI(TabContents* contents);
virtual ~DOMUI();
virtual void RenderViewCreated(RenderViewHost* render_view_host) {}
@@ -89,7 +89,7 @@ class DOMUI {
const Value& arg1,
const Value& arg2);
- WebContents* web_contents() { return web_contents_; }
+ TabContents* tab_contents() { return tab_contents_; }
Profile* GetProfile();
@@ -109,8 +109,8 @@ class DOMUI {
// Execute a string of raw Javascript on the page.
void ExecuteJavascript(const std::wstring& javascript);
- // Non-owning pointer to the WebContents this DOMUI is associated with.
- WebContents* web_contents_;
+ // Non-owning pointer to the TabContents this DOMUI is associated with.
+ TabContents* tab_contents_;
// The DOMMessageHandlers we own.
std::vector<DOMMessageHandler*> handlers_;